@@ -66,14 +66,13 @@ define('io.ox/tours/mail', [
         .step()
             .title(gt('Further functions'))
             .content(gt('In this area you can find further functions, e.g. for adding attachments.'))
-            .spotlight('.active [data-extension-id=composetoolbar]')
+            .hotspot('.active [data-extension-id=composetoolbar] > div:first')
             .end()
         .step()
             .title(gt('Entering the E-Mail text'))
             .content(gt('Enter the E-Mail text into the main area. If the text format was set to HTML in the options, you can format the E-Mail text. To do so select a text part and then click an icon in the formatting bar.'))
             .referTo('.io-ox-mail-compose-container')
-            // use editor class so the selector fits for html and plain text editor
-            .spotlight('.active .mail-compose-contenteditable-fields,.active  .io-ox-mail-compose.container .editor')
+            .hotspot('.active .io-ox-mail-compose.container .editor .editable')
             .end()
         .step()
             .title(gt('Sending the E-Mail'))
